You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@aries.apache.org by da...@apache.org on 2012/01/12 17:49:46 UTC

svn commit: r1230632 - in /aries/trunk/sandbox/jmx-next: jmx-api/src/main/java/org/osgi/jmx/framework/wiring/BundleWiringStateMBean.java jmx-core/src/main/java/org/apache/aries/jmx/framework/wiring/BundleWiringState.java

Author: davidb
Date: Thu Jan 12 16:49:45 2012
New Revision: 1230632

URL: http://svn.apache.org/viewvc?rev=1230632&view=rev
Log:
Collapsing REVISIONS_BUNDLE_WIRING_TYPE and BUNDLE_WIRING_CLOSURE_TYPE into a single BUNDLES_WIRING_TYPE type as their definition is the same.

Modified:
    aries/trunk/sandbox/jmx-next/jmx-api/src/main/java/org/osgi/jmx/framework/wiring/BundleWiringStateMBean.java
    aries/trunk/sandbox/jmx-next/jmx-core/src/main/java/org/apache/aries/jmx/framework/wiring/BundleWiringState.java

Modified: aries/trunk/sandbox/jmx-next/jmx-api/src/main/java/org/osgi/jmx/framework/wiring/BundleWiringStateMBean.java
URL: http://svn.apache.org/viewvc/aries/trunk/sandbox/jmx-next/jmx-api/src/main/java/org/osgi/jmx/framework/wiring/BundleWiringStateMBean.java?rev=1230632&r1=1230631&r2=1230632&view=diff
==============================================================================
--- aries/trunk/sandbox/jmx-next/jmx-core/src/main/java/org/apache/aries/jmx/framework/wiring/BundleWiringState.java (original)
+++ aries/trunk/sandbox/jmx-next/jmx-core/src/main/java/org/apache/aries/jmx/framework/wiring/BundleWiringState.java Thu Jan 12 16:49:45 2012
@@ -84,7 +84,7 @@ public class BundleWiringState implement
     public TabularData getCurrentWiringClosure(long rootBundleId, String namespace) throws IOException {
         Map<BundleRevision, Integer> revisionIDMap = getCurrentRevisionTransitiveRevisionsClosure(rootBundleId, namespace);
 
-        TabularData td = new TabularDataSupport(BundleWiringStateMBean.BUNDLE_WIRING_CLOSURE_TYPE);
+        TabularData td = new TabularDataSupport(BundleWiringStateMBean.BUNDLES_WIRING_TYPE);
         for (Map.Entry<BundleRevision, Integer> entry : revisionIDMap.entrySet()) {
             td.put(getRevisionWiring(entry.getKey(), entry.getValue(), namespace, revisionIDMap));
         }
@@ -172,7 +172,7 @@ public class BundleWiringState implement
         Bundle bundle = FrameworkUtils.resolveBundle(bundleContext, bundleId);
         BundleRevisions revisions = bundle.adapt(BundleRevisions.class);
 
-        TabularData td = new TabularDataSupport(BundleWiringStateMBean.REVISIONS_BUNDLE_WIRING_TYPE);
+        TabularData td = new TabularDataSupport(BundleWiringStateMBean.BUNDLES_WIRING_TYPE);
         for (BundleRevision revision : revisions.getRevisions()) {
             Map<BundleRevision, Integer> revisionIDMap = getRevisionTransitiveClosure(revision, namespace);
             td.put(getRevisionWiring(revision, System.identityHashCode(revision), namespace, revisionIDMap));
@@ -197,7 +197,7 @@ public class BundleWiringState implement
         BundleRevision revision = bundle.adapt(BundleRevision.class);
         revisionIDMap.put(revision, 0);
 
-        TabularData td = new TabularDataSupport(BundleWiringStateMBean.BUNDLE_WIRING_CLOSURE_TYPE);
+        TabularData td = new TabularDataSupport(BundleWiringStateMBean.BUNDLES_WIRING_TYPE);
         for (Map.Entry<BundleRevision, Integer> entry : revisionIDMap.entrySet()) {
             td.put(getRevisionWiring(entry.getKey(), entry.getValue(), namespace, revisionIDMap));
         }
--- aries/trunk/sandbox/jmx-next/jmx-api/src/main/java/org/osgi/jmx/framework/wiring/BundleWiringStateMBean.java (original)
+++ aries/trunk/sandbox/jmx-next/jmx-api/src/main/java/org/osgi/jmx/framework/wiring/BundleWiringStateMBean.java Thu Jan 12 16:49:45 2012
@@ -212,14 +212,10 @@ public interface BundleWiringStateMBean 
                 CAPABILITIES_ITEM,
                 REQUIRED_WIRES_ITEM,
                 PROVIDED_WIRES_ITEM);
-    TabularType REVISIONS_BUNDLE_WIRING_TYPE =
-        Item.tabularType("REVISIONS_BUNDLE_WIRING",
-            "The bundle wiring for all bundle revisions",
-            BUNDLE_WIRING_TYPE,
-            BUNDLE_ID, BUNDLE_REVISION_ID);
 
-    TabularType BUNDLE_WIRING_CLOSURE_TYPE = Item.tabularType("BUNDLE_WIRING_CLOSURE",
-            "A table of bundle wirings describing a full wiring closure",
+    TabularType BUNDLES_WIRING_TYPE =
+        Item.tabularType("BUNDLES_WIRING",
+            "The bundle wiring for all bundle revisions",
             BUNDLE_WIRING_TYPE,
             BUNDLE_ID, BUNDLE_REVISION_ID);
 
@@ -273,7 +269,7 @@ public interface BundleWiringStateMBean 
      * wiring closure contains all the wirings from the root bundle revision to all bundle revisions
      * it is wired to and all their transitive wirings.
      *
      * @see #BUNDLE_WIRING_CLOSURE_TYPE for the details of the TabularData.
      *
      * @param rootBundleId the root bundle of the closure.
      * @param namespace The name space of the requirements and capabilities for which to return information.
@@ -325,7 +321,7 @@ public interface BundleWiringStateMBean 
     /**
      * Returns the bundle wirings for all revisions of the bundle.
      *
      * @see #REVISIONS_BUNDLE_WIRING_TYPE for the details of TabularData.
      *
      * The bundle wirings are in no particular order, and may
      *  change in subsequent calls to this operations.
@@ -344,7 +340,7 @@ public interface BundleWiringStateMBean 
      * wiring closure contains all the wirings from the root bundle revision to all bundle revisions
      * it is wired to and all their transitive wirings.
      *
      * @see #BUNDLE_WIRING_CLOSURE_TYPE for the details of TabularData.
      *
      * The bundle wirings are in no particular order, and may
      * change in subsequent calls to this operation. Furthermore,
@@ -273,7 +269,7 @@ public interface BundleWiringStateMBean 
      * it is wired to and all their transitive wirings.
      *
-     * @see #BUNDLE_WIRING_CLOSURE_TYPE for the details of the TabularData.
+     * @see #BUNDLES_WIRING_TYPE for the details of the TabularData.
      *
      * @param rootBundleId the root bundle of the closure.
@@ -325,7 +321,7 @@ public interface BundleWiringStateMBean 
      * Returns the bundle wirings for all revisions of the bundle.
      *
-     * @see #REVISIONS_BUNDLE_WIRING_TYPE for the details of TabularData.
+     * @see #BUNDLES_WIRING_TYPE for the details of TabularData.
      *
      * The bundle wirings are in no particular order, and may
@@ -344,7 +340,7 @@ public interface BundleWiringStateMBean 
      * it is wired to and all their transitive wirings.
      *
-     * @see #BUNDLE_WIRING_CLOSURE_TYPE for the details of TabularData.
+     * @see #BUNDLES_WIRING_TYPE for the details of TabularData.
      *
      * The bundle wirings are in no particular order, and may

Modified: aries/trunk/sandbox/jmx-next/jmx-core/src/main/java/org/apache/aries/jmx/framework/wiring/BundleWiringState.java
URL: http://svn.apache.org/viewvc/aries/trunk/sandbox/jmx-next/jmx-core/src/main/java/org/apache/aries/jmx/framework/wiring/BundleWiringState.java?rev=1230632&r1=1230631&r2=1230632&view=diff
==============================================================================